@@ -35,7 +35,7 @@
 
 import re
 from logging import getLogger
-from typing import List  # noqa: F401
+from typing import Any  # noqa: F401
 
 import ldap
 from ldap.filter import filter_format
@@ -242,19 +242,21 @@ class object(univention.admin.handlers.simpleLdap):
     }
 
     def _post_unmap(self, info, values):
+        # type: (univention.admin.handlers._Properties, univention.admin.handlers._Attributes) -> univention.admin.handlers._Properties
         value = values.get('univentionNagiosNotificationOptions', [b''])[0]
         if value:
-            options = value.split(b',')  # type: List[bytes]
+            options = value.split(b',')  # type: list[bytes]
             for key, value in self.OPTION_BITS.items():
                 info[key] = '1' if value in options else '0'
 
         return info
 
     def open(self):
+        # type: () -> None
         super(object, self).open()
         _re = re.compile(r'^([^.]+)\.(.+?)$')
         # convert host FQDN to host DN
-        hostlist = []
+        hostlist = []  # type: list[str]
         hosts = self.oldattr.get('univentionNagiosHostname', [])
         for host in [x.decode('UTF-8') for x in hosts]:
             # split into relDomainName and zoneName
@@ -274,19 +276,20 @@ class object(univention.admin.handlers.simpleLdap):
                     # find dn of host that is related to given aRecords
                     res = self.lo.search(filter=filter)
                     if res:
-                        hostlist.append(res[0][0])  # type: List[str]
+                        hostlist.append(res[0][0])
 
         self['assignedHosts'] = hostlist
 
         self.save()
 
     def _ldap_modlist(self):
+        # type: () -> list[tuple[str, Any, Any]]
         ml = univention.admin.handlers.simpleLdap._ldap_modlist(self)
 
-        options = []
+        options = []  # type: list[bytes]
         for key, value in self.OPTION_BITS.items():
             if self[key] == '1':
-                options.append(value)  # type: List[bytes]
+                options.append(value)
 
         # univentionNagiosNotificationOptions is required in LDAP schema
         if not options:
