@@ -64,6 +64,7 @@ operations = ['add', 'edit', 'remove', 'search']
 policy_oc = 'univentionPolicyRegistry'
 policy_apply_to = ["computers/domaincontroller_master", "computers/domaincontroller_backup", "computers/domaincontroller_slave", "computers/memberserver"]
 policy_position_dn_prefix = "cn=config-registry"
+multivalue_policy = True
 childs = False
 short_description = _('Policy: Univention Configuration Registry')
 object_name = _('Univention Configuration Registry policy')
@@ -122,6 +123,7 @@ class object(univention.admin.handlers.simplePolicy):
     module = module
 
     def _post_unmap(self, info, oldattr):
+        # type: (univention.admin.handlers._Properties, univention.admin.handlers._Attributes) -> univention.admin.handlers._Properties
         info['registry'] = sorted(
             [self._ucr_unhexlify(attr_name), ldap_value[0].decode('UTF-8').strip()]
             for attr_name, ldap_value in oldattr.items()
