@@ -33,13 +33,15 @@
 import importlib
 import os.path
 from glob import glob
+from typing import Any, Dict, Iterable, Iterator, List, Tuple, Type, cast  # noqa: F401
 
 
 class Plugin(type):
     """Meta class for plugins."""
 
     def __new__(mcs, name, bases, attrs):
-        new_cls = super(Plugin, mcs).__new__(mcs, name, bases, attrs)
+        # type: (Type[Plugin], str, Tuple[type, ...], Dict[str, Any]) -> Plugin
+        new_cls = cast(Plugin, super(Plugin, mcs).__new__(mcs, name, bases, attrs))
         Plugins.add_plugin(new_cls)
         return new_cls
 
@@ -47,10 +49,11 @@ class Plugin(type):
 class Plugins(object):
     """Register `Plugin` subclasses and iterate over them."""
 
-    _plugins = []
-    _imported = {}
+    _plugins = []  # type: List[Plugin]
+    _imported = {}  # type: Dict[str, bool]
 
     def __init__(self, python_path):
+        # type: (str) -> None
         """
         :param str python_path: fully dotted Python path that the plugins will
                 be found below
@@ -60,6 +63,7 @@ class Plugins(object):
 
     @classmethod
     def add_plugin(cls, plugin):
+        # type: (Plugin) -> None
         """
         Called by `Plugin` meta class to register a new `Plugin` subclass.
 
@@ -68,11 +72,11 @@ class Plugins(object):
         cls._plugins.append(plugin)
 
     def __iter__(self):
+        # type: () -> Iterator[Plugin]
         """
         Iterator for registered `Plugin` subclasses.
 
         :return: `Plugin` subclass
-        :rtype: type
         """
         self.load()
         for plugin in self._plugins:
@@ -80,10 +84,12 @@ class Plugins(object):
                 yield plugin
 
     def load(self):
+        # type: () -> None
         """Load plugins."""
         if self._imported.get(self.python_path):
             return
         base_module = importlib.import_module(self.python_path)
+        assert base_module.__file__
         base_module_dir = os.path.dirname(base_module.__file__)
         path = os.path.join(base_module_dir, '*.py')
         for pymodule in glob(path):
